FmodBindings class
Looked-up FMOD entry points over an opened FmodLibrary.
Constructors
- FmodBindings(FmodLibrary library)
Properties
-
Channel_IsPlaying
→ _D2<
Pointer< Void> , Pointer<Int32> > -
final
-
Channel_Set3DAttributes
→ _D3<
Pointer< Void> , Pointer<FmodVector> , Pointer<FmodVector> > -
final
-
Channel_Set3DDopplerLevel
→ int Function(Pointer<
Void> , double) -
final
-
Channel_Set3DMinMaxDistance
→ int Function(Pointer<
Void> , double, double) -
final
-
Channel_SetChannelGroup
→ _D2<
Pointer< Void> , Pointer<Void> > -
final
-
Channel_SetMode
→ _D2<
Pointer< Void> , int> -
final
-
Channel_SetPaused
→ _D2<
Pointer< Void> , int> -
final
-
Channel_SetPitch
→ int Function(Pointer<
Void> , double) -
final
-
Channel_SetVolume
→ int Function(Pointer<
Void> , double) -
final
-
Channel_Stop
→ _D1<
Pointer< Void> > -
final
-
ChannelGroup_AddGroup
→ int Function(Pointer<
Void> , Pointer<Void> , int, Pointer<Pointer< )Void> > -
final
-
ChannelGroup_SetPaused
→ _D2<
Pointer< Void> , int> -
final
-
ChannelGroup_SetVolume
→ int Function(Pointer<
Void> , double) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Sound_GetLength
→ int Function(Pointer<
Void> , Pointer<Uint32> , int) -
final
-
Sound_Release
→ _D1<
Pointer< Void> > -
final
-
Studio_Bank_Unload
→ _D1<
Pointer< Void> > -
final
-
Studio_Bus_SetVolume
→ int Function(Pointer<
Void> , double) -
final
-
Studio_EventDescription_CreateInstance
→ _D2<
Pointer< Void> , Pointer<Pointer< >Void> > -
final
-
Studio_EventInstance_GetPlaybackState
→ _D2<
Pointer< Void> , Pointer<Int32> > -
final
-
Studio_EventInstance_Release
→ _D1<
Pointer< Void> > -
final
-
Studio_EventInstance_Set3DAttributes
→ _D2<
Pointer< Void> , Pointer<Fmod3dAttributes> > -
final
-
Studio_EventInstance_SetParameterByName
→ int Function(Pointer<
Void> , Pointer<Utf8> , double, int) -
final
-
Studio_EventInstance_SetPaused
→ _D2<
Pointer< Void> , int> -
final
-
Studio_EventInstance_SetPitch
→ int Function(Pointer<
Void> , double) -
final
-
Studio_EventInstance_SetProperty
→ int Function(Pointer<
Void> , int, double) -
final
-
Studio_EventInstance_SetVolume
→ int Function(Pointer<
Void> , double) -
final
-
Studio_EventInstance_Start
→ _D1<
Pointer< Void> > -
final
-
Studio_EventInstance_Stop
→ _D2<
Pointer< Void> , int> -
final
-
Studio_System_Create
→ _D2<
Pointer< Pointer< , int>Void> > -
final
-
Studio_System_GetBus
→ _D3<
Pointer< Void> , Pointer<Utf8> , Pointer<Pointer< >Void> > -
final
-
Studio_System_GetCoreSystem
→ _D2<
Pointer< Void> , Pointer<Pointer< >Void> > -
final
-
Studio_System_GetEvent
→ _D3<
Pointer< Void> , Pointer<Utf8> , Pointer<Pointer< >Void> > -
final
-
Studio_System_Initialize
→ int Function(Pointer<
Void> , int, int, int, Pointer<Void> ) -
final
-
Studio_System_LoadBankFile
→ int Function(Pointer<
Void> , Pointer<Utf8> , int, Pointer<Pointer< )Void> > -
final
-
Studio_System_LoadBankMemory
→ int Function(Pointer<
Void> , Pointer<Uint8> , int, int, int, Pointer<Pointer< )Void> > -
final
-
Studio_System_Release
→ _D1<
Pointer< Void> > -
final
-
Studio_System_SetListenerAttributes
→ int Function(Pointer<
Void> , int, Pointer<Fmod3dAttributes> , Pointer<FmodVector> ) -
final
-
Studio_System_Update
→ _D1<
Pointer< Void> > -
final
-
System_CreateChannelGroup
→ _D3<
Pointer< Void> , Pointer<Utf8> , Pointer<Pointer< >Void> > -
final
-
System_CreateSound
→ int Function(Pointer<
Void> , Pointer<Utf8> , int, Pointer<Void> , Pointer<Pointer< )Void> > -
final
-
System_GetMasterChannelGroup
→ _D2<
Pointer< Void> , Pointer<Pointer< >Void> > -
final
-
System_PlaySound
→ int Function(Pointer<
Void> , Pointer<Void> , Pointer<Void> , int, Pointer<Pointer< )Void> > -
final
-
System_SetOutput
→ _D2<
Pointer< Void> , int> -
final
Methods
-
check(
int result, String operation) → void -
Throws FmodException when
resultis not FMOD_OK. -
checkChannel(
int result, String operation) → bool - Like check, but treats an invalid or stolen channel handle as a clean "finished" signal (returns false) instead of an error.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited